#include <cstdint>
#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <unordered_map>
#include <unordered_set>
#include <cmath>
#include <string>
#include <algorithm>
#include <functional>

using namespace std;

using NodeFunc = std::function<void (int)>;
using EdgeFunc = std::function<void (int, int)>;

void node_nop(int) {}
void edge_nop(int, int) {}

class DFS {
public:
    int const n;
    std::vector<std::vector<int>> const& adj;
    std::vector<bool> visited;
    EdgeFunc explore;
    NodeFunc discover, finish;

    DFS(std::vector<std::vector<int>> const& adj) : n(adj.size()), adj(adj), visited(n, false), explore(edge_nop), discover(node_nop), finish(node_nop) {}

    void dfs_from(int node) {
        if (visited[node]) return;
        visited[node] = true;
        discover(node);
        for (int child : adj[node]) {
            explore(node, child);
            dfs_from(child);
        }
        finish(node);
    }
    void run() {
        for (int node = 0; node < n; ++node) {
            dfs_from(node);
        }
    }
    DFS& on_explore(EdgeFunc f) {
        explore = f;
        return *this;
    }
    DFS& on_discover(NodeFunc f) {
        discover = f;
        return *this;
    }
    DFS& on_finish(NodeFunc f) {
        finish = f;
        return *this;
    }
};



std::vector<int> topsort(std::vector<std::vector<int>> const& adj, vector<int>& biec) {
    std::vector<int> result;
    result.reserve(adj.size());
    DFS(adj).on_finish([&] (int node) { result.push_back(node); }).run();
    std::reverse(result.begin(), result.end());
    for (int i = 0; i < adj.size(); ++i) {
        biec[i] = result.size();
    }
    return result;
}

int main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);
    std::cout.tie(nullptr);
    int t;
    std::cin >> t;
    for (int j = 0; j < t; ++j) {
        int n, m;
        std::cin >> n >> m;
        vector<vector<int>> adj(n);
        vector<int> biec(n);
        vector<pair<int, int>> edges(m);
        for (int i = 0; i < m; ++i) {
            int u, v;
            cin >> u >> v;
            --u;
            --v;
            adj[u].push_back(v);
            edges[i] = {u, v};
        }
        vector<int> result = topsort(adj, biec);
        int count = 0;
        for (auto &edge : edges) {
            count += biec[edge.first] <= biec[edge.second];
        }
        if (count >= ceil(m / 2.)) {
            for (auto i : result) {
                std::cout << i + 1 << ' ';
            }
        } else {
            std::cout << -1;
        }
        std::cout << '\n';
    }
    return 0;
}
